@@ -8,3 +8,5 @@ from course import Course, CourseCollection
 from attendance import Attendance, AttendanceCollection
 from course_grade import CourseGrade, CourseGradeCollection
 from enrollment import Enrollment, EnrollmentCollection
+from period import Period, PeriodCollection
+from attendance_code import AttendanceCode, AttendanceCodeCollection
